"use strict";
exports.__esModule = true;
var parsePinyinWithNumbers_1 = require("./parsePinyinWithNumbers");
describe('parsePinyinWithNumbers', function () {
    test('empty text', function () {
        expect(parsePinyinWithNumbers_1.parsePinyinWithNumbers('')).toMatchSnapshot();
    });
    test('simple syllable', function () {
        expect(parsePinyinWithNumbers_1.parsePinyinWithNumbers('zhi1')).toMatchSnapshot();
    });
    test('simple syllable with erhua', function () {
        expect(parsePinyinWithNumbers_1.parsePinyinWithNumbers('huar5')).toMatchSnapshot();
    });
    test('no erhua with er', function () {
        expect(parsePinyinWithNumbers_1.parsePinyinWithNumbers('err2')).toMatchSnapshot();
    });
    test('initial only', function () {
        expect(parsePinyinWithNumbers_1.parsePinyinWithNumbers('zh')).toMatchSnapshot();
    });
    test('two syllables', function () {
        expect(parsePinyinWithNumbers_1.parsePinyinWithNumbers('e4e4')).toMatchSnapshot();
    });
    test('text only', function () {
        expect(parsePinyinWithNumbers_1.parsePinyinWithNumbers('aerzh1zi 555')).toMatchSnapshot();
    });
    test('text at the start', function () {
        expect(parsePinyinWithNumbers_1.parsePinyinWithNumbers('.zhi2')).toMatchSnapshot();
    });
    test('text at the end', function () {
        expect(parsePinyinWithNumbers_1.parsePinyinWithNumbers('zhi2.')).toMatchSnapshot();
    });
    test('mixed text and syllables', function () {
        expect(parsePinyinWithNumbers_1.parsePinyinWithNumbers('AA zhi4')).toMatchSnapshot();
    });
    test('changwen', function () {
        expect(parsePinyinWithNumbers_1.parsePinyinWithNumbers('chang2wen1')).toMatchInlineSnapshot("\n      Array [\n        Object {\n          \"erhua\": false,\n          \"final\": \"ang\",\n          \"initial\": \"ch\",\n          \"isCapitalized\": false,\n          \"tone\": 2,\n          \"type\": \"PINYIN_SYLLABLE\",\n        },\n        Object {\n          \"erhua\": false,\n          \"final\": \"en\",\n          \"initial\": \"w\",\n          \"isCapitalized\": false,\n          \"tone\": 1,\n          \"type\": \"PINYIN_SYLLABLE\",\n        },\n      ]\n    ");
    });
});
